==> zio-aws-chimesdkmediapipelines_3-6.20.78.1-sources.jar: zio/aws/chimesdkmediapipelines/model/ContentShareLayoutOption.scala <==
package zio.aws.chimesdkmediapipelines.model
import scala.jdk.CollectionConverters.*
sealed trait ContentShareLayoutOption {
  def unwrap: software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption
}
object ContentShareLayoutOption {
  def wrap(
      value: software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption
  ): zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption =
    value match {
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.PRESENTER_ONLY =>
        val r = PresenterOnly
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.HORIZONTAL =>
        val r = Horizontal
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.VERTICAL =>
        val r = Vertical
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.UNKNOWN_TO_SDK_VERSION
  }
  case object PresenterOnly
      extends zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.PRESENTER_ONLY
  }
  case object Horizontal
      extends zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.HORIZONTAL
  }
  case object Vertical
      extends zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.VERTICAL
  }
}

==> zio-aws-chimesdkmediapipelines_3-6.20.162.2-sources.jar: zio/aws/chimesdkmediapipelines/model/ContentShareLayoutOption.scala <==
package zio.aws.chimesdkmediapipelines.model
import scala.jdk.CollectionConverters.*
sealed trait ContentShareLayoutOption {
  def unwrap: software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption
}
object ContentShareLayoutOption {
  def wrap(
      value: software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption
  ): zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption =
    value match {
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.PRESENTER_ONLY =>
        val r = PresenterOnly
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.HORIZONTAL =>
        val r = Horizontal
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.VERTICAL =>
        val r = Vertical
        r
      case software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.ACTIVE_SPEAKER_ONLY =>
        val r = ActiveSpeakerOnly
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.UNKNOWN_TO_SDK_VERSION
  }
  case object PresenterOnly
      extends zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.PRESENTER_ONLY
  }
  case object Horizontal
      extends zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.HORIZONTAL
  }
  case object Vertical
      extends zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.VERTICAL
  }
  case object ActiveSpeakerOnly
      extends zio.aws.chimesdkmediapipelines.model.ContentShareLayoutOption {
    override def unwrap
        : software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption =
      software.amazon.awssdk.services.chimesdkmediapipelines.model.ContentShareLayoutOption.ACTIVE_SPEAKER_ONLY
  }
}
